==> V1.0.0.zip: fe_kd_server/src/router/routes.js <==
export default [
    {
        path: '/',
        redirect: '/login'
    },
    {
        path: '/',
        component: () => import('../components/common/Home.vue'),
        meta: { title: '自述文件' },
        children: [
            {
                path: '/personalcenter',
                component: () => import('../components/page/PersonalCenter.vue'),
                meta: {
                    title: '个人中心'
                }
            },
            {
                path: '/dashboard',
                component: () => import('../components/page/Dashboard.vue'),
                meta: { title: '班级教学' }
            },
            {
                path: '/addclass',
                component: () => import('../components/page/AddClass.vue'),
                meta: { title: '新建班级' }
            },
            {
                path: '/achievement',
                component: () => import('../components/page/Achievement.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/experiment',
                component: () => import('../components/page/Experiment.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/experimentVir',
                component: () => import('../components/page/ExperimentVir.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/experimentTeach',
                component: () => import('../components/page/ExperimentTeach.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/addexperiment',
                component: () => import('../components/page/AddExperiment.vue'),
                meta: { title: '修改分数' }
            },
            {
                path: '/showexperiment',
                component: () => import('../components/page/ShowExperiment.vue'),
                meta: { title: '查看成绩报告' }
            },
            {
                path: '/user',
                component: () => import('../components/page/User.vue'),
                meta: { title: '用户管理' }
            },
            {
                path: '/evaluation',
                component: () => import('../components/page/Evaluation.vue'),
                meta: { title: '测评管理' }
            },
            {
                path: '/project',
                component: () => import('../components/page/Project.vue'),
                meta: { title: '实验项目管理' }
            },
            {
                path: '/addproject',
                component: () => import('../components/page/AddProject.vue'),
                meta: { title: '新增项目' }
            },
            {
                path: '/program',
                component: () => import('../components/page/Program.vue'),
                meta: { title: '查看判分点' }
            },
            {
                path: '/programOptions',
                component: () => import('../components/page/ProgramOptions.vue'),
                meta: { title: '查看判分点' }
            },
            {
                path: '/student',
                component: () => import('../components/page/Student.vue'),
                meta: { title: '学生管理' }
            },
            {
                path: '/backstage',
                component: () => import('../components/page/Backstage.vue'),
                meta: { title: '业务后台' }
            },
            {
                path: '/report',
                component: () => import('../components/page/Report.vue'),
                meta: { title: '实验报告管理' }
            },
            {
                path: '/reportconfig',
                component: () => import('../components/page/ReportConfig.vue'),
                meta: { title: '实验报告配置' }
            },
            {
                path: '/teachercomment',
                component: () => import('../components/page/TeacherComment.vue'),
                meta: { title: '老师评语' }
            },
            {
                path: '/staff',
                component: () => import('../components/page/Staff.vue'),
                meta: { title: '用户管理' }
            },
            {
                path: '/system',
                component: () => import('../components/page/System.vue'),
                meta: { title: '系统设置' }
            },
            
            {
                // 国际化组件
                path: '/i18n',
                component: () => import(/* webpackChunkName: "i18n" */ '../components/page/I18n.vue'),
                meta: { title: '国际化' }
            },
            {
                path: '/404',
                component: () => import(/* webpackChunkName: "404" */ '../components/page/404.vue'),
                meta: { title: '404' }
            },
            {
                path: '/403',
                component: () => import(/* webpackChunkName: "403" */ '../components/page/403.vue'),
                meta: { title: '403' }
            }
        ]
    },
    {
        path: '/login',
        component: () => import(/* webpackChunkName: "login" */ '../components/page/Login.vue'),
        meta: { title: '登录' }
    },
    {
        path: '*',
        redirect: '/404'
    }
]

==> V1.0.1.zip: fe_kd_server/src/router/routes.js <==
export default [
    {
        path: '/',
        redirect: '/login'
    },
    {
        path: '/',
        component: () => import('../components/common/Home.vue'),
        meta: { title: '自述文件' },
        children: [
            {
                path: '/personalcenter',
                component: () => import('../components/page/PersonalCenter.vue'),
                meta: {
                    title: '个人中心'
                }
            },
            {
                name: 'dashboard',
                path: '/dashboard',
                component: () => import('../components/page/Dashboard.vue'),
                meta: { title: '班级教学' }
            },
            {
                path: '/classinfo',
                component: () => import('../components/page/ClassInfo.vue'),
                meta: { title: '班级教学' }
            },
            {
                path: '/addMatch',
                component: () => import('../components/page/AddMatch.vue'),
                meta: { title: '新建班级' }
            },
            {
                name: 'assessment',
                path: '/assessment',
                component: () => import('../components/page/Assessment.vue'),
                meta: { title: '考核管理' }
            },
            {
                path: '/addAssessment',
                component: () => import('../components/page/AddAssessment.vue'),
                meta: { title: '考核管理' }
            },
            {
                name: 'achievement',
                path: '/achievement',
                component: () => import('../components/page/Achievement.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/experiment',
                component: () => import('../components/page/Experiment.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/experimentVir',
                component: () => import('../components/page/ExperimentVir.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/experimentTeach',
                component: () => import('../components/page/ExperimentTeach.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/experimentAss',
                component: () => import('../components/page/ExperimentAss.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/classExperimentAss',
                component: () => import('../components/page/classExperimentAss.vue'),
                meta: { title: '成绩管理' }
            },
            {
                path: '/addexperiment',
                component: () => import('../components/page/AddExperiment.vue'),
                meta: { title: '修改分数' }
            },
            {
                path: '/showexperiment',
                component: () => import('../components/page/ShowExperiment.vue'),
                meta: { title: '查看成绩报告' }
            },
            {
                path: '/user',
                component: () => import('../components/page/User.vue'),
                meta: { title: '用户管理' }
            },
            {
                name: 'evaluation',
                path: '/evaluation',
                component: () => import('../components/page/Evaluation.vue'),
                meta: { title: '测评管理' }
            },
            {
                name: 'project',
                path: '/project',
                component: () => import('../components/page/Project.vue'),
                meta: { title: '实验项目管理' }
            },
            {
                path: '/addproject',
                component: () => import('../components/page/AddProject.vue'),
                meta: { title: '新增项目' }
            },
            {
                path: '/program',
                component: () => import('../components/page/Program.vue'),
                meta: { title: '查看判分点' }
            },
            {
                path: '/programOptions',
                component: () => import('../components/page/ProgramOptions.vue'),
                meta: { title: '查看判分点' }
            },
            {
                name: 'student',
                path: '/student',
                component: () => import('../components/page/Student.vue'),
                meta: { title: '学生管理' }
            },
            {
                name: 'match',
                path: '/match',
                component: () => import('../components/page/Match.vue'),
                meta: { title: '竞赛实验' }
            },
            {
                name: 'backstage',
                path: '/backstage',
                component: () => import('../components/page/Backstage.vue'),
                meta: { title: '业务后台' }
            },
            {
                path: '/report',
                component: () => import('../components/page/Report.vue'),
                meta: { title: '实验报告管理' }
            },
            {
                path: '/reportconfig',
                component: () => import('../components/page/ReportConfig.vue'),
                meta: { title: '实验报告配置' }
            },
            {
                path: '/teachercomment',
                component: () => import('../components/page/TeacherComment.vue'),
                meta: { title: '老师评语' }
            },
            {
                name: 'staff',
                path: '/staff',
                component: () => import('../components/page/Staff.vue'),
                meta: { title: '用户管理' }
            },
            {
                name: 'system',
                path: '/system',
                component: () => import('../components/page/System.vue'),
                meta: { title: '系统设置' }
            },
            
            {
                // 国际化组件
                path: '/i18n',
                component: () => import(/* webpackChunkName: "i18n" */ '../components/page/I18n.vue'),
                meta: { title: '国际化' }
            },
            {
                path: '/404',
                component: () => import(/* webpackChunkName: "404" */ '../components/page/404.vue'),
                meta: { title: '404' }
            },
            {
                path: '/403',
                component: () => import(/* webpackChunkName: "403" */ '../components/page/403.vue'),
                meta: { title: '403' }
            }
        ]
    },
    {
        path: '/login',
        component: () => import(/* webpackChunkName: "login" */ '../components/page/Login.vue'),
        meta: { title: '登录' }
    },
    {
        path: '*',
        redirect: '/404'
    }
]
